package fr.lri.keller.td7;


import android.app.Activity;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.app.Fragment;
import android.preference.CheckBoxPreference;
import android.preference.Preference;
import android.preference.PreferenceFragment;
import android.preference.SwitchPreference;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

// Fragment de préférences

public class SettingsFragment extends PreferenceFragment implements SharedPreferences.OnSharedPreferenceChangeListener {

    // Interface permettant la communication entre fragments via l'activité à laquelle ils sont
    // attachés, qui doit implanter cette interface
    public interface OnFragmentInteractionListener {
        public void onSetTextSize(boolean b);
        public void onSetTextColor(boolean b);
    }

    private OnFragmentInteractionListener mListener;

    // Constructeur, requis car on hérite de Fragment
    public SettingsFragment() {}

    // Création du fragment
    @Override
    public void onCreate(Bundle savedInstanceState) {
        // Appel de la méthode de la super-classe
        super.onCreate(savedInstanceState);

        // Chargement de l'interface XML
        addPreferencesFromResource(R.xml.preferences);
    }

    // Récupération de l'écouteur de l'activité lorsque le fragment est attaché
    @Override
    public void onAttach(Activity activity) {
        super.onAttach(activity);
        try {
            mListener = (OnFragmentInteractionListener) activity;
        } catch (ClassCastException e) {
            throw new ClassCastException(activity.toString()
                    + " must implement OnFragmentInteractionListener");
        }
    }

    // On supprime l'accès à l'écouteur de l'activité lorsque le fragment est détaché
    @Override
    public void onDetach() {
        super.onDetach();
        mListener = null;
    }

    // Lancement de l'écouteur de préférence lors du démarrage du fragment
    @Override
    public void onResume() {
        super.onResume();
        getPreferenceScreen().getSharedPreferences().registerOnSharedPreferenceChangeListener(this);
    }

    // Arrêt de l'écouteur de préférence lors de l'arrêt du fragment
    @Override
    public void onPause() {
        getPreferenceScreen().getSharedPreferences().unregisterOnSharedPreferenceChangeListener(this);
        super.onPause();
    }

    // Actions à effectuer lorsque les préférences sont modifiées
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences,
                                          String key) {
        if (key.equals("text_size")) {
            // Récupération de la préférence associée à la clé
            CheckBoxPreference pref = (CheckBoxPreference) findPreference(key);

            // Action à effectuer
            mListener.onSetTextSize(pref.isChecked());
        }
        if (key.equals("text_color")) {
            // Récupération de la préférence associée à la clé
            SwitchPreference pref = (SwitchPreference) findPreference(key);

            // Action à effectuer
            mListener.onSetTextColor(pref.isChecked());
        }
    }
}
