package fr.lri.keller.td7;

import android.app.FragmentManager;
import android.app.FragmentTransaction;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

// Activité principale

public class TD7Activity extends AppCompatActivity implements SettingsFragment.OnFragmentInteractionListener {

    private FragmentManager fragmentManager;
    private TD7ActivityFragment fragTD7;
    private SettingsFragment fragSettings = new SettingsFragment();

    TextView textViewBonjour;

    private final static float TEXT_SIZE_SMALL=14;
    private final static float TEXT_SIZE_LARGE=28;

    private final static int NOIR = 0xFF000000;
    private final static int ROUGE = 0xFFFF0000;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_td7);

        // On récupère les objets de l'interface
        textViewBonjour = (TextView) findViewById(R.id.textViewBonjour);

        // On récupère le gestionnaire de fragments
        fragmentManager = getFragmentManager();

        // On récupère le fragment potentiellement existant
        fragTD7 = (TD7ActivityFragment) fragmentManager.findFragmentById(R.id.fragment);

        // S'il n'existe pas, on le crée et on l'attache
        if (fragTD7 == null) {
            fragTD7 = new TD7ActivityFragment();
            FragmentTransaction transaction = fragmentManager.beginTransaction();
            transaction.add(R.id.fragment, fragTD7);
            transaction.commit();
        }

        // La première fois que l'application est lancée, on lit les préférences par défaut du
        // fichier XML
        PreferenceManager.setDefaultValues(this, R.xml.preferences, false);

        // On réalise l'affichage selon les préférences actuelles (mais non les préférences par
        // défaut)
        SharedPreferences sharedPref = PreferenceManager.getDefaultSharedPreferences(this);
        onSetTextSize(sharedPref.getBoolean("text_size", false));
        onSetTextColor(sharedPref.getBoolean("text_color", false));
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_td7, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        switch (id) {

            // Menu de préférences
            case R.id.action_settings:
                // On attache le fragment si ça n'est pas déjà le cas
                if (!fragSettings.isAdded()) {
                    FragmentTransaction transaction = fragmentManager.beginTransaction();
                    transaction.replace(R.id.fragment, fragSettings);
                    transaction.addToBackStack(null);
                    transaction.commit();
                }
                return true;

            // Réinitialisation des préférences
            case R.id.action_reset_settings:
                // On réinitialise la table des préférences
                PreferenceManager.getDefaultSharedPreferences(this).edit().clear().commit();
                // On relit les valeurs par défaut du fichier XML
                PreferenceManager.setDefaultValues(this, R.xml.preferences, true);

                // On réalise l'affichage selon ces préférences
                SharedPreferences sharedPref = PreferenceManager.getDefaultSharedPreferences(this);
                onSetTextSize(sharedPref.getBoolean("text_size", false));
                onSetTextColor(sharedPref.getBoolean("text_color", false));

                return true;

            default:
                return super.onOptionsItemSelected(item);
        }
    }

    // Méthode appelée lorsque l'utilisateur appuie sur le bouton de retour
    @Override
    public void onBackPressed() {
        if (fragSettings.isAdded()) {
            // Première version, avec une transaction pour détacher le fragment
            // FragmentTransaction transaction = fragmentManager.beginTransaction();
            // transaction.replace(R.id.fragment, fragTD7);
            // transaction.commit();

            // Deuxième version, utilisant la pile
            fragmentManager.popBackStack();
        } else {
            super.onBackPressed();
        }
    }

    // Méthodes mettant à jour la taille du texte
    public void setTextSize(boolean b) {
        if (b) {
            textViewBonjour.setTextSize(TEXT_SIZE_LARGE);
        } else {
            textViewBonjour.setTextSize(TEXT_SIZE_SMALL);
        }
    }

    public void onSetTextSize(boolean b) {
        setTextSize(b);
        fragTD7.setTextSize(b);
    }

    // Méthodes mettant à jour la couleur du texte
    public void setTextColor(boolean b) {
        if (b) {
            textViewBonjour.setTextColor(ROUGE);
        } else {
            textViewBonjour.setTextColor(NOIR);
        }
    }

    public void onSetTextColor(boolean b) {
        setTextColor(b);
        fragTD7.setTextColor(b);
    }
}
